@@ -1,7 +1,5 @@
 package Class::Meta::AccessorBuilder;
 
-# $Id: AccessorBuilder.pm 3893 2008-05-15 03:12:02Z david $
-
 =head1 NAME
 
 Class::Meta::AccessorBuilder - Perl style accessor generation
@@ -193,7 +191,7 @@ be used in the set accessor (mutator) to validate new attribute values.
 
 use strict;
 use Class::Meta;
-our $VERSION = '0.62';
+our $VERSION = '0.64';
 
 sub build_attr_get {
     UNIVERSAL::can($_[0]->package, $_[0]->name);
@@ -380,16 +378,20 @@ __END__
 
 =head1 SUPPORT
 
-This module is stored in an open repository at the following address:
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/class-meta/>. Feel free to fork and
+contribute!
 
-L<https://svn.kineticode.com/Class-Meta/trunk/>
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/class-meta/issues/> or by sending mail to
+L<bug-Class-Meta.cpan.org|mailto:bug-Class-Meta.cpan.org>.
 
 Patches against Class::Meta are welcome. Please send bug reports to
 <bug-class-meta@rt.cpan.org>.
 
 =head1 AUTHOR
 
-David Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
@@ -423,7 +425,7 @@ generated accessors.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2008, David Wheeler. Some Rights Reserved.
+Copyright (c) 2002-2011, David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
