@@ -1,7 +1,5 @@
 package Class::Meta::Types::String;
 
-# $Id: String.pm 3879 2008-05-13 03:39:45Z david $
-
 =head1 NAME
 
 Class::Meta::Types::String - String data types
@@ -39,7 +37,7 @@ creating data types.
 
 use strict;
 use Class::Meta::Type;
-our $VERSION = '0.61';
+our $VERSION = '0.64';
 
 sub import {
     my ($pkg, $builder) = @_;
@@ -63,16 +61,20 @@ __END__
 
 =head1 SUPPORT
 
-This module is stored in an open repository at the following address:
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/class-meta/>. Feel free to fork and
+contribute!
 
-L<https://svn.kineticode.com/Class-Meta/trunk/>
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/class-meta/issues/> or by sending mail to
+L<bug-Class-Meta.cpan.org|mailto:bug-Class-Meta.cpan.org>.
 
 Patches against Class::Meta are welcome. Please send bug reports to
 <bug-class-meta@rt.cpan.org>.
 
 =head1 AUTHOR
 
-David Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
@@ -110,7 +112,7 @@ Other data type modules:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2008, David Wheeler. Some Rights Reserved.
+Copyright (c) 2002-2011, David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
